Skip to content
This repository was archived by the owner on Aug 14, 2025. It is now read-only.
This repository was archived by the owner on Aug 14, 2025. It is now read-only.

Compile error #3

Description

@AIBSCT80

Hi, I got the compiling error in the directory: nways_multi_gpu/labs/CFD/English/C/source_code/cuda

jacobi_memcpy.cu(278): error: too few arguments in function call
{ cudaError_t cudaStatus = cudaSetDevice( ); if (cudaSuccess != cudaStatus) fprintf(
jacobi_memcpy.cu(287): error: expected an expression
jacobi_kernel<<< , >>>( );
^

jacobi_memcpy.cu(287): error: expected an expression
jacobi_kernel<<< , >>>( );
^

jacobi_memcpy.cu(287): error: too few arguments in function call
jacobi_kernel<<< , >>>( );
^

jacobi_memcpy.cu(290): error: expected an expression
{ cudaError_t cudaStatus = cudaMemcpyAsync( , , sizeof(float), ); if (cudaSuccess != cudaStatus) fprintf(
^

jacobi_memcpy.cu(290): error: expected an expression
{ cudaError_t cudaStatus = cudaMemcpyAsync( , , sizeof(float), ); if (cudaSuccess != cudaStatus) fprintf(
^

jacobi_memcpy.cu(290): error: expected an expression
{ cudaError_t cudaStatus = cudaMemcpyAsync( , , sizeof(float), ); if (cudaSuccess != cudaStatus) fprintf(
^

jacobi_memcpy.cu(299): error: too few arguments in function call
{ cudaError_t cudaStatus = cudaSetDevice( ); if (cudaSuccess != cudaStatus) fprintf(
^

jacobi_memcpy.cu(302): error: expected an expression
{ cudaError_t cudaStatus = cudaMemcpyAsync( , , nx * sizeof(float), ); if (cudaSuccess != cudaStatus) fprintf(
^

jacobi_memcpy.cu(302): error: expected an expression
{ cudaError_t cudaStatus = cudaMemcpyAsync( , , nx * sizeof(float), ); if (cudaSuccess != cudaStatus) fprintf(
^

jacobi_memcpy.cu(302): error: expected an expression
{ cudaError_t cudaStatus = cudaMemcpyAsync( , , nx * sizeof(float), ); if (cudaSuccess != cudaStatus) fprintf(
^

jacobi_memcpy.cu(305): error: expected an expression
{ cudaError_t cudaStatus = cudaMemcpyAsync( , , nx * sizeof(float), ); if (cudaSuccess != cudaStatus) fprintf(
^

jacobi_memcpy.cu(305): error: expected an expression
{ cudaError_t cudaStatus = cudaMemcpyAsync( , , nx * sizeof(float), ); if (cudaSuccess != cudaStatus) fprintf(
^

jacobi_memcpy.cu(305): error: expected an expression
{ cudaError_t cudaStatus = cudaMemcpyAsync( , , nx * sizeof(float), ); if (cudaSuccess != cudaStatus) fprintf(
^

jacobi_memcpy.cu(311): error: too few arguments in function call
{ cudaError_t cudaStatus = cudaSetDevice( ); if (cudaSuccess != cudaStatus) fprintf(
^

jacobi_memcpy.cu(312): error: expected an expression
{ cudaError_t cudaStatus = ; if (cudaSuccess != cudaStatus) fprintf(
^

16 errors detected in the compilation of "jacobi_memcpy.cu"

Is there something missing in the compiling configuration?

Thanks

Activity

Sign up for free to join this conversation on GitHub. Already have an account? Sign in to comment

Metadata

Metadata

Assignees

No one assigned

    Labels

    No labels
    No labels

    Type

    No type

    Projects

    No projects

      Milestone

      No milestone

      Relationships

      None yet

      Development

      No branches or pull requests

      Issue actions